@@ -1,8 +1,4 @@
-try:
-  import json
-except ImportError:
-  import simplejson as json
-
+import json
 
 class SMTPAPIHeader(object):
 
@@ -61,4 +57,4 @@ class SMTPAPIHeader(object):
     self.data['filters'][app]['settings'][setting] = val
 
   def json_string(self):
-    return json.dumps(self.data)
\ No newline at end of file
+    return json.dumps(self.data)
